/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Community System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.io.Writer;
import java.io.IOException;
import javax.servlet.ServletRequest;
import com.silverwrist.util.StringUtil;
import com.silverwrist.venice.ValidationException;

public class CDFormCategoryHeader implements CDFormField
{
  private String caption;
  private String rtext;
  private boolean enabled;

  public CDFormCategoryHeader(String caption)
  {
    this.caption = caption;
    this.rtext = null;
    this.enabled = true;

  } // end constructor

  public CDFormCategoryHeader(String caption, String rtext)
  {
    this.caption = caption;
    this.rtext = rtext;
    this.enabled = true;

  } // end constructor

  protected CDFormCategoryHeader(CDFormCategoryHeader other)
  {
    this.caption = other.caption;
    this.rtext = other.rtext;
    this.enabled = true;

  } // end constructor

  public void renderHere(Writer out, RenderData rdat) throws IOException
  {
    out.write("<TR VALIGN=MIDDLE><TD ALIGN=RIGHT>");
    if (!enabled)
      out.write("<FONT COLOR=\"silver\">");
    out.write("<B>" + StringUtil.encodeHTML(caption) + ":</B>");
    if (!enabled)
      out.write("</FONT>");
    out.write("</TD><TD ALIGN=LEFT>");
    if (rtext==null)
      out.write("&nbsp;");
    else
    { // display in the correct state
      if (!enabled)
	out.write("<FONT COLOR=\"silver\">");
      out.write(StringUtil.encodeHTML(rtext));
      if (!enabled)
	out.write("</FONT>");

    } // end else

    out.write("</TD></TR>\n");

  } // end renderHere

  public String getName()
  {
    return null;

  } // end getName

  public String getValue()
  {
    return null;

  } // end getValue

  public void setValue(String value)
  { // do nothing
  } // end setValue

  public boolean isRequired()
  {
    return false;

  } // end isRequired

  public void validate()
  { // do nothing
  } // end validate

  public CDCommandButton findButton(String name)
  {
    return null;

  } // end findButton

  public boolean isEnabled()
  {
    return enabled;

  } // end isEnabled

  public void setEnabled(boolean flag)
  {
    enabled = flag;

  } // end setEnabled

  public CDFormField duplicate()
  {
    return new CDFormCategoryHeader(this);

  } // end clone

} // end class CDFormCategoryHeader

