/*
 * The contents of this file are subject to the Mozilla Public License Version 1.1
 * (the "License"); you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at <http://www.mozilla.org/MPL/>.
 * 
 * Software distributed under the License is distributed on an "AS IS" basis, WITHOUT
 * WARRANTY OF ANY KIND, either express or implied. See the License for the specific
 * language governing rights and limitations under the License.
 * 
 * The Original Code is the Venice Web Communities System.
 * 
 * The Initial Developer of the Original Code is Eric J. Bowersox <erbo@silcom.com>,
 * for Silverwrist Design Studios.  Portions created by Eric J. Bowersox are
 * Copyright (C) 2001 Eric J. Bowersox/Silverwrist Design Studios.  All Rights Reserved.
 * 
 * Contributor(s): 
 */
package com.silverwrist.venice.servlets.format;

import java.util.*;
import javax.servlet.*;
import javax.servlet.http.*;
import com.silverwrist.venice.core.*;

public class ConferenceActivity implements JSPRender
{
  /*--------------------------------------------------------------------------------
   * Static data members
   *--------------------------------------------------------------------------------
   */

  // Attribute name for request attribute
  protected static final String ATTR_NAME = "com.silverwrist.venice.content.ConferenceActivity";

  /*--------------------------------------------------------------------------------
   * Attributes
   *--------------------------------------------------------------------------------
   */

  private SIGContext sig;               // the SIG we're in
  private ConferenceContext conf;       // the conference being listed
  private boolean posters;              // is this a list of posters?
  private List records;                 // the actual data records

  /*--------------------------------------------------------------------------------
   * Constructor
   *--------------------------------------------------------------------------------
   */

  public ConferenceActivity(SIGContext sig, ConferenceContext conf, boolean posters) throws DataException
  {
    this.sig = sig;
    this.conf = conf;
    this.posters = posters;
    if (posters)
      this.records = conf.getActivePosters();
    else
      this.records = conf.getActiveReaders();

  } // end constructor

  /*--------------------------------------------------------------------------------
   * External static functions
   *--------------------------------------------------------------------------------
   */

  public static ConferenceActivity retrieve(ServletRequest request)
  {
    return (ConferenceActivity)(request.getAttribute(ATTR_NAME));

  } // end retrieve

  /*--------------------------------------------------------------------------------
   * Implementations from interface VeniceContent
   *--------------------------------------------------------------------------------
   */

  public String getPageTitle(RenderData rdat)
  {
    if (posters)
      return "Users Posting in Conference " + conf.getName();
    else
      return "Users Reading Conference " + conf.getName();

  } // end getPageTitle

  /*--------------------------------------------------------------------------------
   * Implementations from interface JSPRender
   *--------------------------------------------------------------------------------
   */

  public void store(ServletRequest request)
  {
    request.setAttribute(ATTR_NAME,this);

  } // end store

  public String getTargetJSPName()
  {
    return "conf_activity.jsp";

  } // end getTargetJSPName

  /*--------------------------------------------------------------------------------
   * External operations
   *--------------------------------------------------------------------------------
   */

  public String getConfName()
  {
    return conf.getName();

  } // end getConfName

  public String getLocator()
  {
    return "sig=" + sig.getSIGID() + "&conf=" + conf.getConfID();

  } // end getLocator

  public boolean isPosterReport()
  {
    return posters;

  } // end isPosterReport

  public boolean anyElements()
  {
    return (records.size()>0);

  } // end anyElements

  public Iterator getRecordsIterator()
  {
    return records.iterator();

  } // end getRecordsIterator

} // end class ConferenceActivity
